@@ -2,6 +2,8 @@
 An advance math module that performs math operations and all the necessary math functions such as absolute, mean,
 median, mode, factorial, sin, cos, tan etc
 
+It Includes fractions to solve and simplify the fractions.
+
 Pure math module which has no external modules(math, numpy and sympy etc.) imported.
 
 Author: Roshaan Mehmood
@@ -16,4 +18,6 @@ from pythmath.math import absolute, area_rect, area_square, area_circle, area_tr
     percentage, perc_error, abs_error, rel_error, stdev, pstdev, mean_abs_dev, zscore, stderr, samp_err, sort, \
     count, variance, covariance, arr_sum, arr_2d_sum, nCr, nPr, minimum, maximum, stats_range, midrange, fibonacci, \
     mult_two_lst, multiply_lst, square_lst, pow_lst, isfloat, pos_neg, prime_factors, prime_numbers, odd_numbers, \
-    even_numbers
+    even_numbers, quad_eqn, num_factors, angle, arc_length, arc_length_deg, avg_rate_change
+
+from pythmath.fractions import fraction, frac_to_float, float_to_frac
