@@ -1169,3 +1169,112 @@ def even_numbers(s_range, end_range):
         if odd:
             odd_list.append(num)
     return odd_list
+
+
+def quad_eqn(a, b, c):
+    """
+    Solves the quadratic equation and gets the roots of a quadratic equation.
+
+    Quadratic Equation: In algebra, a quadratic equation is any equation that can be rearranged in standard form as
+    where x represents an unknown, and a, b, and c represent known numbers, where a ≠ 0. If a = 0, then the equation
+    is linear, not quadratic, as there is no ax^2 term.
+
+    :param a: Value of a
+    :param b: Value of b
+    :param c: Value of c
+    :return: Roots of a quadratic equation
+    """
+    discriminant = b ** 2 - 4 * a * c
+    if discriminant >= 0:
+        x_1 = (-b + square_root(discriminant)) / 2 * a
+        x_2 = (-b - square_root(discriminant)) / 2 * a
+    else:
+        x_1 = complex((-b / (2 * a)), square_root(-discriminant) / (2 * a))
+        x_2 = complex((-b / (2 * a)), -square_root(-discriminant) / (2 * a))
+
+    if a == 0:
+        return "Value of a is 0, thus the equation is not a quadratic equation."
+
+    if discriminant > 0:
+        return "The function has two distinct real roots: {} and {}".format(x_1, x_2)
+    elif discriminant == 0:
+        return "The function has one double root: {}".format(x_1)
+    else:
+        # print("The function has two complex (conjugate) roots: ", x_1, " and ", x_2)
+        return "The function has two complex (conjugate) roots: {} and {}".format(x_1, x_2)
+
+
+def num_factors(x):
+    """
+    Factorise a number 'x' and returns the list of factors.
+
+    :param x: Value of x
+    :return: List of factors of a number.
+    """
+    factors = []
+    for i in range(1, x + 1):
+        if x % i == 0:
+            factors.append(i)
+    return factors
+
+
+def angle(arc_len, r):
+    """
+    Calculates the angle from arc length and radius, it basically uses central angle formula.
+
+    Arc Length: Arc length is the distance between two points along a section of a curve. Determining the length of
+    an irregular arc segment by approximating the arc segment as connected line segments is also called rectification
+    of a curve.
+
+    :param arc_len: Value of arc length
+    :param r: Value of radius.
+    :return: Value of angle from arc length and radius
+    """
+    return arc_len * 360 / (2 * pi * r)
+
+
+def arc_length(a, r):
+    """
+    Calculates the arc length from angle (in radians) and radius.
+
+    Arc Length: Arc length is the distance between two points along a section of a curve. Determining the length of
+    an irregular arc segment by approximating the arc segment as connected line segments is also called rectification
+    of a curve.
+
+    :param a: Value of angle in radians.
+    :param r: Value of radius.
+    :return: Value of arc length
+    """
+    return a * r
+
+
+def arc_length_deg(a, r):
+    """
+    Calculates the arc length from angle (in degrees) and radius.
+
+    Arc Length: Arc length is the distance between two points along a section of a curve. Determining the length of
+    an irregular arc segment by approximating the arc segment as connected line segments is also called rectification
+    of a curve.
+
+    :param a: Value of angle in degrees.
+    :param r: Value of radius.
+    :return: Value of arc length
+    """
+    return 2 * pi * r * a / 360
+
+
+def avg_rate_change(f_a, f_b, a, b):
+    """
+    Calculates the average rate of change from f(a) and f(b) calculated from a general function f(x).
+
+    Average Rate of Change: The Average Rate of Change function is defined as the average rate at which one quantity
+    is changing with respect to something else changing. In simple terms, an average rate of change function is a
+    process that calculates the amount of change in one item divided by the corresponding amount of change in another.
+
+    :param f_a: f(a) value from general f(x) function
+    :param f_b: f(b) value from general f(x) function
+    :param a: Value of a
+    :param b: Value of b
+    :return: Average rate of change from f(a) and f(b) calculated from a general function f(x).
+    """
+    return (f_b - f_a) / (b - a)
